@@ -143,9 +143,10 @@ cb_urgent_blink_button_toggled (GtkToggleButton *toggle, GtkWidget *repeat_urgen
 }
 
 static void
-cb_restore_on_move_check_button_toggled (GtkToggleButton *toggle, GtkWidget *button)
+cb_borderless_maximize_button_toggled (GtkToggleButton *toggle, GtkWidget *titleless_maximize_check)
 {
-    gtk_widget_set_sensitive (button, gtk_toggle_button_get_active (toggle));
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (titleless_maximize_check), FALSE);
+    gtk_widget_set_sensitive (titleless_maximize_check, gtk_toggle_button_get_active (toggle));
 }
 
 static void
@@ -181,7 +182,7 @@ wm_tweaks_dialog_configure_widgets (GtkBuilder *builder)
     GtkWidget *easy_click_combo_box = GTK_WIDGET (gtk_builder_get_object (builder, "easy_click_combo_box"));
     GtkWidget *raise_with_any_button_check = GTK_WIDGET (gtk_builder_get_object (builder, "raise_with_any_button_check"));
     GtkWidget *borderless_maximize_check = GTK_WIDGET (gtk_builder_get_object (builder, "borderless_maximize_check"));
-    GtkWidget *restore_on_move_check = GTK_WIDGET (gtk_builder_get_object (builder, "restore_on_move_check"));
+    GtkWidget *titleless_maximize_check = GTK_WIDGET (gtk_builder_get_object (builder, "titleless_maximize_check"));
     GtkWidget *tile_on_move_check = GTK_WIDGET (gtk_builder_get_object (builder, "tile_on_move_check"));
     GtkWidget *snap_resist_check = GTK_WIDGET (gtk_builder_get_object (builder, "snap_resist_check"));
     GtkWidget *urgent_blink = GTK_WIDGET (gtk_builder_get_object (builder, "urgent_blink"));
@@ -204,10 +205,11 @@ wm_tweaks_dialog_configure_widgets (GtkBuilder *builder)
     GtkWidget *use_compositing_box = GTK_WIDGET (gtk_builder_get_object (builder, "use_compositing_box"));
 
     GtkWidget *unredirect_overlays_check = GTK_WIDGET (gtk_builder_get_object (builder, "unredirect_overlays_check"));
+    GtkWidget *sync_to_vblank_check = GTK_WIDGET (gtk_builder_get_object (builder, "sync_to_vblank_check"));
+    GtkWidget *cycle_preview_check = GTK_WIDGET (gtk_builder_get_object (builder, "cycle_preview_check"));
     GtkWidget *show_frame_shadow_check = GTK_WIDGET (gtk_builder_get_object (builder, "show_frame_shadow_check"));
     GtkWidget *show_popup_shadow_check = GTK_WIDGET (gtk_builder_get_object (builder, "show_popup_shadow_check"));
     GtkWidget *show_dock_shadow_check = GTK_WIDGET (gtk_builder_get_object (builder, "show_dock_shadow_check"));
-    GtkWidget *sync_to_vblank_check = GTK_WIDGET (gtk_builder_get_object (builder, "sync_to_vblank_check"));
 
     GtkWidget *frame_opacity_scale = GTK_WIDGET (gtk_builder_get_object (builder, "frame_opacity_scale"));
     GtkWidget *inactive_opacity_scale = GTK_WIDGET (gtk_builder_get_object (builder, "inactive_opacity_scale"));
@@ -268,13 +270,10 @@ wm_tweaks_dialog_configure_widgets (GtkBuilder *builder)
                       "toggled",
                       G_CALLBACK (cb_activate_action_none_radio_toggled),
                       xfwm4_channel);
-#if 0
-    /* OF: Actually, this is not related, so this callback is not needed */
-    g_signal_connect (G_OBJECT (prevent_focus_stealing_check),
+    g_signal_connect (G_OBJECT (borderless_maximize_check),
                       "toggled",
-                      G_CALLBACK (cb_prevent_focus_stealing_check_button_toggled),
-                      prevent_focus_stealing_box);
-#endif
+                      G_CALLBACK (cb_borderless_maximize_button_toggled),
+                      titleless_maximize_check);
     g_signal_connect (G_OBJECT (placement_center_option),
                       "toggled",
                       G_CALLBACK (cb_activate_placement_center_radio_toggled),
@@ -295,10 +294,6 @@ wm_tweaks_dialog_configure_widgets (GtkBuilder *builder)
                       "toggled",
                       G_CALLBACK (cb_urgent_blink_button_toggled),
                       repeat_urgent_blink);
-    g_signal_connect (G_OBJECT (restore_on_move_check),
-                      "toggled",
-                      G_CALLBACK (cb_restore_on_move_check_button_toggled),
-                      tile_on_move_check);
 
     /* Bind easy properties */
     /* Cycling tab */
@@ -343,9 +338,9 @@ wm_tweaks_dialog_configure_widgets (GtkBuilder *builder)
                             G_TYPE_BOOLEAN,
                             (GObject *)borderless_maximize_check, "active");
     xfconf_g_property_bind (xfwm4_channel,
-                            "/general/restore_on_move",
+                            "/general/titleless_maximize",
                             G_TYPE_BOOLEAN,
-                            (GObject *)restore_on_move_check, "active");
+                            (GObject *)titleless_maximize_check, "active");
     xfconf_g_property_bind (xfwm4_channel,
                             "/general/tile_on_move",
                             G_TYPE_BOOLEAN,
@@ -368,8 +363,8 @@ wm_tweaks_dialog_configure_widgets (GtkBuilder *builder)
                             (GObject *)mousewheel_rollup, "active");
     gtk_widget_set_sensitive (repeat_urgent_blink,
                               gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (urgent_blink)));
-    gtk_widget_set_sensitive (tile_on_move_check,
-                              gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (restore_on_move_check)));
+    gtk_widget_set_sensitive (titleless_maximize_check,
+                              gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (borderless_maximize_check)));
 
     /* Workspaces tab */
     xfconf_g_property_bind (xfwm4_channel,
@@ -404,6 +399,18 @@ wm_tweaks_dialog_configure_widgets (GtkBuilder *builder)
                             "/general/unredirect_overlays",
                             G_TYPE_BOOLEAN,
                             (GObject *)unredirect_overlays_check, "active");
+#ifdef HAVE_LIBDRM
+    xfconf_g_property_bind (xfwm4_channel,
+                            "/general/sync_to_vblank",
+                            G_TYPE_BOOLEAN,
+                            (GObject *)sync_to_vblank_check, "active");
+#else
+    gtk_widget_hide (sync_to_vblank_check);
+#endif
+    xfconf_g_property_bind (xfwm4_channel,
+                            "/general/cycle_preview",
+                            G_TYPE_BOOLEAN,
+                            (GObject *)cycle_preview_check, "active");
     xfconf_g_property_bind (xfwm4_channel,
                             "/general/show_frame_shadow",
                             G_TYPE_BOOLEAN,
@@ -416,15 +423,6 @@ wm_tweaks_dialog_configure_widgets (GtkBuilder *builder)
                             "/general/show_dock_shadow",
                             G_TYPE_BOOLEAN,
                             (GObject *)show_dock_shadow_check, "active");
-#ifdef HAVE_LIBDRM
-    xfconf_g_property_bind (xfwm4_channel,
-                            "/general/sync_to_vblank",
-                            G_TYPE_BOOLEAN,
-                            (GObject *)sync_to_vblank_check, "active");
-#else
-    gtk_widget_hide (sync_to_vblank_check);
-#endif
-
     xfconf_g_property_bind (xfwm4_channel,
                             "/general/frame_opacity",
                             G_TYPE_INT,
