@@ -89,7 +89,7 @@ frameLeft (Client * c)
     g_return_val_if_fail (c != NULL, 0);
     if (FLAG_TEST (c->xfwm_flags, XFWM_FLAG_HAS_BORDER)
         && !FLAG_TEST (c->flags, CLIENT_FLAG_FULLSCREEN)
-        && (!FLAG_TEST (c->flags, CLIENT_FLAG_MAXIMIZED)
+        && (!FLAG_TEST_ALL (c->flags, CLIENT_FLAG_MAXIMIZED)
             || !(c->screen_info->params->borderless_maximize)))
     {
         return c->screen_info->sides[SIDE_LEFT][ACTIVE].width;
@@ -105,7 +105,7 @@ frameRight (Client * c)
     g_return_val_if_fail (c != NULL, 0);
     if (FLAG_TEST (c->xfwm_flags, XFWM_FLAG_HAS_BORDER)
         && !FLAG_TEST (c->flags, CLIENT_FLAG_FULLSCREEN)
-        && (!FLAG_TEST (c->flags, CLIENT_FLAG_MAXIMIZED)
+        && (!FLAG_TEST_ALL (c->flags, CLIENT_FLAG_MAXIMIZED)
             || !(c->screen_info->params->borderless_maximize)))
     {
         return c->screen_info->sides[SIDE_RIGHT][ACTIVE].width;
@@ -119,7 +119,7 @@ frameTop (Client * c)
     TRACE ("entering frameTop");
 
     g_return_val_if_fail (c != NULL, 0);
-    if (CLIENT_HAS_TITLE (c))
+    if (CLIENT_HAS_FRAME (c))
     {
         return c->screen_info->title[TITLE_3][ACTIVE].height;
     }
@@ -134,7 +134,7 @@ frameBottom (Client * c)
     g_return_val_if_fail (c != NULL, 0);
     if (FLAG_TEST (c->xfwm_flags, XFWM_FLAG_HAS_BORDER)
         && !FLAG_TEST (c->flags, CLIENT_FLAG_FULLSCREEN)
-        && (!FLAG_TEST (c->flags, CLIENT_FLAG_MAXIMIZED)
+        && (!FLAG_TEST_ALL (c->flags, CLIENT_FLAG_MAXIMIZED)
             || !(c->screen_info->params->borderless_maximize)))
     {
         return c->screen_info->sides[SIDE_BOTTOM][ACTIVE].height;
@@ -150,7 +150,7 @@ frameX (Client * c)
     g_return_val_if_fail (c != NULL, 0);
     if (FLAG_TEST (c->xfwm_flags, XFWM_FLAG_HAS_BORDER)
         && !FLAG_TEST (c->flags, CLIENT_FLAG_FULLSCREEN)
-        && (!FLAG_TEST (c->flags, CLIENT_FLAG_MAXIMIZED)
+        && (!FLAG_TEST_ALL (c->flags, CLIENT_FLAG_MAXIMIZED)
             || !(c->screen_info->params->borderless_maximize)))
     {
         return c->x - frameLeft (c);
@@ -180,7 +180,7 @@ frameWidth (Client * c)
     g_return_val_if_fail (c != NULL, 0);
     if (FLAG_TEST (c->xfwm_flags, XFWM_FLAG_HAS_BORDER)
         && !FLAG_TEST (c->flags, CLIENT_FLAG_FULLSCREEN)
-        && (!FLAG_TEST (c->flags, CLIENT_FLAG_MAXIMIZED)
+        && (!FLAG_TEST_ALL (c->flags, CLIENT_FLAG_MAXIMIZED)
             || !(c->screen_info->params->borderless_maximize)))
     {
         return c->width + frameLeft (c) + frameRight (c);
@@ -320,7 +320,7 @@ frameTopLeftWidth (Client * c, int state)
     TRACE ("entering frameTopLeftWidth");
 
     g_return_val_if_fail (c != NULL, 0);
-    if (FLAG_TEST (c->flags, CLIENT_FLAG_MAXIMIZED)
+    if (FLAG_TEST_ALL (c->flags, CLIENT_FLAG_MAXIMIZED)
         && c->screen_info->params->borderless_maximize)
     {
         return 0;
@@ -335,7 +335,7 @@ frameTopRightWidth (Client * c, int state)
     TRACE ("entering frameTopRightWidth");
 
     g_return_val_if_fail (c != NULL, 0);
-    if (FLAG_TEST (c->flags, CLIENT_FLAG_MAXIMIZED)
+    if (FLAG_TEST_ALL (c->flags, CLIENT_FLAG_MAXIMIZED)
         && c->screen_info->params->borderless_maximize)
     {
         return 0;
@@ -349,7 +349,7 @@ frameButtonOffset (Client *c)
     TRACE ("entering frameButtonOffset");
 
     g_return_val_if_fail (c != NULL, 0);
-    if (FLAG_TEST (c->flags, CLIENT_FLAG_MAXIMIZED)
+    if (FLAG_TEST_ALL (c->flags, CLIENT_FLAG_MAXIMIZED)
         && c->screen_info->params->borderless_maximize)
     {
         return MAX (0, c->screen_info->params->maximized_offset);
@@ -537,7 +537,7 @@ frameCreateTitlePixmap (Client * c, int state, int left, int right, xfwmPixmap *
     xfwmPixmapCreate (screen_info, top_pm, width, top_height);
     xfwmPixmapCreate (screen_info, title_pm, width, frameTop (c));
     gpixmap = gdk_pixmap_foreign_new (title_pm->pixmap);
-    gdk_drawable_set_colormap (gpixmap, gdk_screen_get_rgb_colormap (screen_info->gscr));
+    gdk_drawable_set_colormap (gpixmap, gdk_screen_get_system_colormap (screen_info->gscr));
     gc = gdk_gc_new (gpixmap);
 
     if (w1 > 0)
@@ -1058,7 +1058,7 @@ frameDrawWin (Client * c)
         }
     }
 
-    if (CLIENT_HAS_TITLE (c))
+    if (CLIENT_HAS_FRAME (c))
     {
         /* First, hide the buttons that we don't have... */
         for (i = 0; i < BUTTON_COUNT; i++)
@@ -1180,7 +1180,7 @@ frameDrawWin (Client * c)
                 &screen_info->corners[CORNER_BOTTOM_RIGHT][state]);
         }
 
-        if (FLAG_TEST (c->flags, CLIENT_FLAG_MAXIMIZED)
+        if (FLAG_TEST_ALL (c->flags, CLIENT_FLAG_MAXIMIZED)
             && (c->screen_info->params->borderless_maximize))
         {
             xfwmWindowHide (&c->sides[SIDE_LEFT]);
