@@ -18,7 +18,7 @@
 
         oroborus - (c) 2001 Ken Lynch
         Metacity - (c) 2001 Havoc Pennington
-        xfwm4    - (c) 2002-2011 Olivier Fourdan
+        xfwm4    - (c) 2002-2015 Olivier Fourdan
 
  */
 
@@ -105,7 +105,7 @@
 #define NET_WM_BOTTOMRIGHT                      2
 #define NET_WM_BOTTOMLEFT                       3
 
-#define NET_WM_OPAQUE                           0xffffffff
+#define NET_WM_OPAQUE                           G_MAXUINT32
 
 #define STRUTS_LEFT                             0
 #define STRUTS_RIGHT                            1
@@ -205,6 +205,11 @@ void                     initNetDesktopInfo                     (DisplayInfo *,
                                                                  int,
                                                                  int,
                                                                  int);
+void                     setNetDesktopInfo                      (DisplayInfo *,
+                                                                 Window,
+                                                                 int,
+                                                                 int,
+                                                                 int);
 void                     setUTF8StringHint                      (DisplayInfo *,
                                                                  Window,
                                                                  int,
@@ -260,7 +265,7 @@ gboolean                 getRGBIconData                         (DisplayInfo *,
                                                                  unsigned long *);
 gboolean                 getOpacity                             (DisplayInfo *,
                                                                  Window,
-                                                                 guint *);
+                                                                 guint32 *);
 gboolean                 getOpacityLock                         (DisplayInfo *,
                                                                  Window);
 gboolean                 setXAtomManagerOwner                   (DisplayInfo *,
@@ -273,7 +278,6 @@ gboolean                 setAtomIdManagerOwner                  (DisplayInfo *,
                                                                  Window);
 void                     updateXserverTime                      (DisplayInfo *);
 guint32                  getXServerTime                         (DisplayInfo *);
-
 #ifdef ENABLE_KDE_SYSTRAY_PROXY
 gboolean                 checkKdeSystrayWindow                  (DisplayInfo *,
                                                                  Window);
