@@ -18,7 +18,7 @@
 
         Metacity - (c) 2001 Havoc Pennington
         libwnck  - (c) 2001 Havoc Pennington
-        xfwm4    - (c) 2002-2011 Olivier Fourdan
+        xfwm4    - (c) 2002-2015 Olivier Fourdan
  */
 
 #ifndef INC_ICONS_H
@@ -32,11 +32,15 @@
 #include <X11/Xutil.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 
-#include "display.h"
+#include "screen.h"
+#include "client.h"
 
-GdkPixbuf               *getAppIcon                             (DisplayInfo *,
+GdkPixbuf               *getAppIcon                             (ScreenInfo *,
                                                                  Window,
-                                                                 int,
-                                                                 int);
+                                                                 guint,
+                                                                 guint);
+GdkPixbuf               *getClientIcon                          (Client *,
+                                                                 guint,
+                                                                 guint);
 
 #endif /* INC_ICONS_H */
