@@ -315,15 +315,6 @@ clientRaise (Client * c, Window wsibling)
      * by clicking inside.
      */
 
-    if (c == clientGetFocus ())
-    {
-        clientPassGrabMouseButton (c);
-    }
-    else
-    {
-        clientPassGrabMouseButton (NULL);
-    }
-
     if (g_list_length (screen_info->windows_stack) < 1)
     {
         return;
@@ -530,7 +521,6 @@ clientLower (Client * c, Window wsibling)
          */
         clientApplyStackList (screen_info);
         clientSetNetClientList (screen_info, display_info->atoms[NET_CLIENT_LIST_STACKING], screen_info->windows_stack);
-        clientPassGrabMouseButton (NULL);
         clientPassFocus (screen_info, c, NULL);
         if (screen_info->last_raise == c)
         {
@@ -549,8 +539,7 @@ clientAdjustFullscreenLayer (Client *c, gboolean set)
 
     if (set)
     {
-        if (FLAG_TEST(c->xfwm_flags, XFWM_FLAG_LEGACY_FULLSCREEN)
-            || FLAG_TEST(c->flags, CLIENT_FLAG_FULLSCREEN))
+        if (FLAG_TEST(c->flags, CLIENT_FLAG_FULLSCREEN))
         {
             clientSetLayer (c, WIN_LAYER_FULLSCREEN);
             return TRUE;
@@ -564,12 +553,6 @@ clientAdjustFullscreenLayer (Client *c, gboolean set)
             clientSetLayer (c, c->fullscreen_old_layer);
             return TRUE;
         }
-        if (FLAG_TEST(c->xfwm_flags, XFWM_FLAG_LEGACY_FULLSCREEN))
-        {
-            TRACE ("Moving \"%s\" (0x%lx) to layer %d", c->name, c->window, WIN_LAYER_FULLSCREEN);
-            clientSetLayer (c, WIN_LAYER_NORMAL);
-            return TRUE;
-        }
     }
     return FALSE;
 }
@@ -607,7 +590,6 @@ clientAddToList (Client * c)
     screen_info->windows_stack = g_list_append (screen_info->windows_stack, c);
 
     clientSetNetClientList (screen_info, display_info->atoms[NET_CLIENT_LIST], screen_info->windows);
-    clientSetNetClientList (screen_info, display_info->atoms[WIN_CLIENT_LIST], screen_info->windows);
 
     FLAG_SET (c->xfwm_flags, XFWM_FLAG_MANAGED);
 }
@@ -650,7 +632,6 @@ clientRemoveFromList (Client * c)
     screen_info->windows_stack = g_list_remove (screen_info->windows_stack, c);
 
     clientSetNetClientList (screen_info, display_info->atoms[NET_CLIENT_LIST], screen_info->windows);
-    clientSetNetClientList (screen_info, display_info->atoms[WIN_CLIENT_LIST], screen_info->windows);
     clientSetNetClientList (screen_info, display_info->atoms[NET_CLIENT_LIST_STACKING], screen_info->windows_stack);
 
     FLAG_UNSET (c->xfwm_flags, XFWM_FLAG_MANAGED);
@@ -707,7 +688,7 @@ delayed_raise_cb (gpointer data)
     {
         clientRaise (c, None);
     }
-    return (TRUE);
+    return (FALSE);
 }
 
 void
