@@ -16,7 +16,7 @@
         MA 02110-1301, USA.
 
 
-        xfwm4    - (c) 2002-2011 Olivier Fourdan
+        xfwm4    - (c) 2002-2015 Olivier Fourdan
 
  */
 
@@ -27,58 +27,20 @@
 #include "xsync.h"
 
 #ifdef HAVE_XSYNC
-gboolean
-getXSyncCounter (DisplayInfo *display_info, Window window, XSyncCounter *counter)
-{
-    long val;
 
-    g_return_val_if_fail (window != None, FALSE);
-    g_return_val_if_fail (counter != NULL, FALSE);
-    TRACE ("entering getXSyncCounter");
+/* See http://fishsoup.net/misc/wm-spec-synchronization.html */
+#ifndef XSYNC_VALUE_INCREMENT
+#define XSYNC_VALUE_INCREMENT 240
+#endif
 
-    val = 0;
-    if (getHint (display_info, window, NET_WM_SYNC_REQUEST_COUNTER, &val))
-    {
-        *counter = (XSyncCounter) val;
-        return TRUE;
-    }
-
-    return FALSE;
-}
-
-void
-sendXSyncRequest (DisplayInfo *display_info, Window window, XSyncValue value)
-{
-    XClientMessageEvent xev;
-
-    g_return_if_fail (window != None);
-    TRACE ("entering sendXSyncRequest");
-
-    xev.type = ClientMessage;
-    xev.window = window;
-    xev.message_type = display_info->atoms[WM_PROTOCOLS];
-    xev.format = 32;
-    xev.data.l[0] = (long) display_info->atoms[NET_WM_SYNC_REQUEST];
-    xev.data.l[1] = (long) myDisplayGetCurrentTime (display_info);
-    xev.data.l[2] = (long) XSyncValueLow32 (value);
-    xev.data.l[3] = (long) XSyncValueHigh32 (value);
-    xev.data.l[4] = (long) 0L;
-    XSendEvent (display_info->dpy, window, FALSE, NoEventMask, (XEvent *) &xev);
-}
-
-void
-clientIncrementXSyncValue (Client *c)
+static void
+addToXSyncValue (XSyncValue *value, gint i)
 {
     XSyncValue add;
     int overflow;
 
-    g_return_if_fail (c != NULL);
-    g_return_if_fail (c->xsync_counter != None);
-
-    TRACE ("entering clientIncrementXSyncValue");
-
-    XSyncIntToValue (&add, 1);
-    XSyncValueAdd (&c->xsync_value, c->xsync_value, add, &overflow);
+    XSyncIntToValue (&add, i);
+    XSyncValueAdd (value, *value, add, &overflow);
 }
 
 gboolean
@@ -86,7 +48,7 @@ clientCreateXSyncAlarm (Client *c)
 {
     ScreenInfo *screen_info;
     DisplayInfo *display_info;
-    XSyncAlarmAttributes values;
+    XSyncAlarmAttributes attrs;
 
     g_return_val_if_fail (c != NULL, FALSE);
     g_return_val_if_fail (c->xsync_counter != None, FALSE);
@@ -96,16 +58,35 @@ clientCreateXSyncAlarm (Client *c)
     screen_info = c->screen_info;
     display_info = screen_info->display_info;
 
-    XSyncIntToValue (&c->xsync_value, 0);
-    XSyncSetCounter (display_info->dpy, c->xsync_counter, c->xsync_value);
-    XSyncIntToValue (&values.trigger.wait_value, 1);
-    XSyncIntToValue (&values.delta, 1);
+    clientDestroyXSyncAlarm (c);
+    if (FLAG_TEST (c->flags, CLIENT_FLAG_XSYNC_EXT_COUNTER))
+    {
+        /* Get the counter value from the client, if not, bail out... */
+        if (!XSyncQueryCounter(display_info->dpy, c->xsync_counter, &c->xsync_value))
+        {
+            FLAG_UNSET (c->flags, CLIENT_FLAG_XSYNC_EXT_COUNTER);
+            return FALSE;
+        }
+    }
+    else
+    {
+        XSyncIntToValue (&c->xsync_value, 0);
+        XSyncSetCounter (display_info->dpy, c->xsync_counter, c->xsync_value);
+    }
 
-    values.trigger.counter = c->xsync_counter;
-    values.trigger.value_type = XSyncAbsolute;
-    values.trigger.test_type = XSyncPositiveComparison;
-    values.events = True;
+    c->next_xsync_value = c->xsync_value;
+    if (!FLAG_TEST (c->flags, CLIENT_FLAG_XSYNC_EXT_COUNTER) ||
+        (XSyncValueLow32(c->next_xsync_value) % 2 == 0))
+    {
+        addToXSyncValue (&c->next_xsync_value, 1);
+    }
 
+    attrs.trigger.counter = c->xsync_counter;
+    XSyncIntToValue (&attrs.delta, 1);
+    XSyncIntToValue (&attrs.trigger.wait_value, 1);
+    attrs.trigger.value_type = XSyncRelative;
+    attrs.trigger.test_type = XSyncPositiveComparison;
+    attrs.events = TRUE;
     c->xsync_alarm = XSyncCreateAlarm (display_info->dpy,
                                        XSyncCACounter |
                                        XSyncCADelta |
@@ -113,7 +94,7 @@ clientCreateXSyncAlarm (Client *c)
                                        XSyncCATestType |
                                        XSyncCAValue |
                                        XSyncCAValueType,
-                                       &values);
+                                       &attrs);
     return (c->xsync_alarm != None);
 }
 
@@ -124,15 +105,61 @@ clientDestroyXSyncAlarm (Client *c)
     DisplayInfo *display_info;
 
     g_return_if_fail (c != NULL);
-    g_return_if_fail (c->xsync_alarm != None);
-
     TRACE ("entering clientDestroyXSyncAlarm");
 
+    clientXSyncClearTimeout (c);
+    if (c->xsync_alarm != None)
+    {
+        screen_info = c->screen_info;
+        display_info = screen_info->display_info;
+
+        XSyncDestroyAlarm (display_info->dpy, c->xsync_alarm);
+        c->xsync_alarm = None;
+    }
+}
+
+gboolean
+clientGetXSyncCounter (Client * c)
+{
+    ScreenInfo *screen_info;
+    DisplayInfo *display_info;
+    gulong *data;
+    int nitems;
+
+    g_return_val_if_fail (c != NULL, FALSE);
+    TRACE ("entering clientGetXSyncCounter");
+
     screen_info = c->screen_info;
     display_info = screen_info->display_info;
 
-    XSyncDestroyAlarm (display_info->dpy, c->xsync_alarm);
-    c->xsync_alarm = None;
+    data = NULL;
+    if (getCardinalList (display_info, c->window, NET_WM_SYNC_REQUEST_COUNTER, &data, &nitems))
+    {
+        switch (nitems)
+        {
+            case 0:
+                FLAG_UNSET (c->flags, CLIENT_FLAG_XSYNC_EXT_COUNTER);
+                FLAG_UNSET (c->flags, CLIENT_FLAG_XSYNC_ENABLED);
+                break;
+            case 1:
+                c->xsync_counter = (XSyncCounter) data[0];
+                FLAG_UNSET (c->flags, CLIENT_FLAG_XSYNC_EXT_COUNTER);
+                FLAG_SET (c->flags, CLIENT_FLAG_XSYNC_ENABLED);
+                break;
+            default:
+                c->xsync_counter = (XSyncCounter) data[1];
+                FLAG_SET (c->flags, CLIENT_FLAG_XSYNC_EXT_COUNTER);
+                FLAG_SET (c->flags, CLIENT_FLAG_XSYNC_ENABLED);
+                break;
+        }
+    }
+
+    if (data)
+    {
+        XFree (data);
+    }
+
+    return FLAG_TEST (c->flags, CLIENT_FLAG_XSYNC_ENABLED);
 }
 
 void
@@ -142,6 +169,7 @@ clientXSyncClearTimeout (Client * c)
 
     TRACE ("entering clientXSyncClearTimeout");
 
+    FLAG_UNSET (c->flags, CLIENT_FLAG_XSYNC_WAITING);
     if (c->xsync_timeout_id)
     {
         g_source_remove (c->xsync_timeout_id);
@@ -153,23 +181,17 @@ static gboolean
 clientXSyncTimeout (gpointer data)
 {
     Client *c;
-    XWindowChanges wc;
 
     TRACE ("entering clientXSyncTimeout");
 
     c = (Client *) data;
     if (c)
     {
-        TRACE ("XSync timeout for client \"%s\" (0x%lx)", c->name, c->window);
+        g_warning ("XSync timeout for client \"%s\" (0x%lx)", c->name, c->window);
         clientXSyncClearTimeout (c);
-        c->xsync_waiting = FALSE;
-        c->xsync_enabled = FALSE;
 
-        wc.x = c->x;
-        wc.y = c->y;
-        wc.width = c->width;
-        wc.height = c->height;
-        clientConfigure (c, &wc, CWX | CWY | CWWidth | CWHeight, NO_CFG_FLAG);
+        /* Disable XSync for this client */
+        FLAG_UNSET (c->flags, CLIENT_FLAG_XSYNC_ENABLED);
     }
     return (FALSE);
 }
@@ -193,42 +215,57 @@ clientXSyncRequest (Client * c)
 {
     ScreenInfo *screen_info;
     DisplayInfo *display_info;
+    XSyncValue next_value;
+    XClientMessageEvent xev;
 
     g_return_if_fail (c != NULL);
     g_return_if_fail (c->window != None);
 
     TRACE ("entering clientXSyncRequest");
 
+    if (FLAG_TEST (c->flags, CLIENT_FLAG_XSYNC_WAITING))
+    {
+        return;
+    }
+
     screen_info = c->screen_info;
     display_info = screen_info->display_info;
 
-    clientIncrementXSyncValue (c);
-    sendXSyncRequest (display_info, c->window, c->xsync_value);
+    next_value = c->next_xsync_value;
+    addToXSyncValue (&next_value, XSYNC_VALUE_INCREMENT);
+    c->next_xsync_value = next_value;
+
+    xev.type = ClientMessage;
+    xev.window = c->window;
+    xev.message_type = display_info->atoms[WM_PROTOCOLS];
+    xev.format = 32;
+    xev.data.l[0] = (long) display_info->atoms[NET_WM_SYNC_REQUEST];
+    xev.data.l[1] = (long) myDisplayGetCurrentTime (display_info);
+    xev.data.l[2] = (long) XSyncValueLow32 (next_value);
+    xev.data.l[3] = (long) XSyncValueHigh32 (next_value);
+    xev.data.l[4] = (long) (FLAG_TEST (c->flags, CLIENT_FLAG_XSYNC_EXT_COUNTER) ? 1 : 0);
+    XSendEvent (display_info->dpy, c->window, FALSE, NoEventMask, (XEvent *) &xev);
+
     clientXSyncResetTimeout (c);
-    c->xsync_waiting = TRUE;
+    FLAG_SET (c->flags, CLIENT_FLAG_XSYNC_WAITING);
 }
 
-gboolean
-clientXSyncEnable (Client * c)
+void
+clientXSyncUpdateValue (Client *c, XSyncValue value)
 {
-    ScreenInfo *screen_info;
-    DisplayInfo *display_info;
+    g_return_if_fail (c != NULL);
+    TRACE ("entering clientXSyncUpdateValue");
 
-    g_return_val_if_fail (c != NULL, FALSE);
-
-    TRACE ("entering clientXSyncEnable");
-
-    screen_info = c->screen_info;
-    display_info = screen_info->display_info;
-
-    c->xsync_enabled = FALSE;
-    if (display_info->have_xsync)
+    c->xsync_value = value;
+    if (FLAG_TEST (c->flags, CLIENT_FLAG_XSYNC_EXT_COUNTER))
     {
-        if ((c->xsync_counter) && (c->xsync_alarm))
+        if (XSyncValueLow32(c->xsync_value) % 2 == 0)
         {
-            c->xsync_enabled = TRUE;
+            addToXSyncValue (&value, 1);
         }
     }
-    return (c->xsync_enabled);
+    c->next_xsync_value = value;
+    clientXSyncClearTimeout (c);
 }
+
 #endif /* HAVE_XSYNC */
